@@ -239,7 +239,8 @@ weibreg <-
     fit$formula <- formula(Terms)
     fit$call <- call
     fit$events <- n.events 
-    class(fit) <- c("weibreg", "coxreg", "coxph")
+    ##class(fit) <- c("weibreg", "coxreg", "coxph")
+    class(fit) <- c("weibreg", "phreg")
     fit$pfixed <- pfixed
     fit
 }
